diff --git Gruntfile.js Gruntfile.js
index 7d820e1075..0101888be5 100644
--- Gruntfile.js
+++ Gruntfile.js
@@ -1127,8 +1127,11 @@ module.exports = function(grunt) {
 				files: [
 					SOURCE_DIR + '**',
 					'!' + SOURCE_DIR + 'js/**/*.js',
-					// Ignore version control directories.
-					'!' + SOURCE_DIR + '**/.{svn,git}/**'
+					// Ignore version control directories and build files.
+					'!' + SOURCE_DIR + '**/.{svn,git}/**',
+					'!' + SOURCE_DIR + '**/node_modules/**',
+					'!' + SOURCE_DIR + '**/build/**',
+					'!' + SOURCE_DIR + '**/build-*/**',
 				],
 				tasks: ['clean:dynamic', 'copy:dynamic'],
 				options: {
